# dialog_cache_outdated.py - inform the user to update the apt cache
#
#  Copyright (c) 2006 Canonical
#
#  Authors:
#       Sebastian Heinlein <sebastian.heinlein@web.de>
#
#  This program is free software; you can redistribute it and/or
#  modify it under the terms of the GNU General Public License as
#  published by the Free Software Foundation; either version 2 of the
#  License, or (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#  USA

import os
from gi.repository import GObject, Gdk, Gtk
from gettext import gettext as _

from gi.repository import PackageKitGlib as packagekit

from softwareproperties.gtk.utils import *


class ProgressDialog(Gtk.Window):
    """A small helper window to display progress"""

    def __init__(self, parent):
        Gtk.Window.__init__(self, title=_("Refreshing package cache"))
        self.set_transient_for(parent)
        self.set_position(Gtk.WindowPosition.CENTER)
        self.set_border_width(16)
        self.set_modal(True)
        self.set_deletable(False)

        self.set_default_size(300, 75)
        geometry = Gdk.Geometry()
        geometry.min_width = 200
        geometry.min_height = 60
        geometry.max_width = 800
        geometry.max_height = 260
        self.set_geometry_hints(None, geometry, Gdk.WindowHints.MIN_SIZE)
        self.set_geometry_hints(None, geometry, Gdk.WindowHints.MAX_SIZE)

        # create a grid
        self.grid = Gtk.Grid(column_homogeneous=True, row_homogeneous=True,
                             column_spacing=10, row_spacing=10)
        self.add(self.grid)

        # create a progress bar
        self.progressbar = Gtk.ProgressBar()
        self.grid.add(self.progressbar)

class DialogCacheOutdated:
    def __init__(self, parent, datadir):
        """setup up the gtk dialog"""
        self.parent = parent

        setup_ui(self, os.path.join(datadir, "gtkbuilder", "dialog-cache-outofdate.ui"), domain="software-properties")
        self.dialog = self.dialog_cache_outofdate
        self.dialog.set_transient_for(parent)

    def run(self):
        """run the dialog, and if reload was pressed run cache update"""
        res = self.dialog.run()
        self.dialog.hide()
        if res == Gtk.ResponseType.APPLY:
            self.loop = GObject.MainLoop()


            pktask = packagekit.Task()
            pdia = ProgressDialog(self.parent)
            pdia.show_all()
            self.parent.set_sensitive(False)
            try:
                pktask.refresh_cache_sync(False,
                    None,
                    (lambda progress, ptype, data: pdia.progressbar.set_fraction(progress.get_property("percentage") / 100.0)), None)
            except Exception as e:
                print("Error while executing refresh:", e)

            pdia.hide()
            self.parent.set_sensitive(True)

        return res
